@@ -1,20 +1,9 @@
 /*
-    Copyright 2019 Filip Fila <filipfila.kde@gmail.com>
-    Copyright 2013 by Reza Fatahilah Shah <rshah0385@kireihana.com>
-    Copyright 2011, 2012 David Edmundson <kde@davidedmundson.co.uk>
+    SPDX-FileCopyrightText: 2019 Filip Fila <filipfila.kde@gmail.com>
+    SPDX-FileCopyrightText: 2013 Reza Fatahilah Shah <rshah0385@kireihana.com>
+    SPDX-FileCopyrightText: 2011, 2012 David Edmundson <kde@davidedmundson.co.uk>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "sddmauthhelper.h"
 #include "src/config.h"
@@ -62,6 +51,26 @@ static QSharedPointer<KConfig> openConfig(const QString &filePath)
     return QSharedPointer<KConfig>(new KConfig(file.fileName(), KConfig::SimpleConfig));
 }
 
+void SddmAuthHelper::copyDirectoryRecursively(const QString &source, const QString &destination, QSet<QString> &done)
+{
+    if (done.contains(source)) {
+        return;
+    }
+    done.insert(source);
+
+    const QDir sourceDir(source);
+    const auto entries = sourceDir.entryInfoList(QDir::NoDotAndDotDot | QDir::Dirs | QDir::Files);
+    for (const auto &entry : entries) {
+        const auto destinationPath = destination + '/' + entry.fileName();
+        if (entry.isFile()) {
+            copyFile(entry.absoluteFilePath(), destinationPath);
+        } else {
+            QDir().mkpath(destinationPath);
+            copyDirectoryRecursively(entry.absoluteFilePath(), destinationPath, done);
+        }
+    }
+}
+
 void SddmAuthHelper::copyFile(const QString &source, const QString &destination)
 {
     KUser sddmUser(QStringLiteral("sddm"));
@@ -70,7 +79,9 @@ void SddmAuthHelper::copyFile(const QString &source, const QString &destination)
         QFile::remove(destination);
     }
 
-    QFile::copy(source, destination);
+    if (!QFile::copy(source, destination)) {
+        qWarning() << "Could not copy" << source << "to" << destination;
+    }
     const char *destinationConverted = destination.toLocal8Bit().data();
     if (chown(destinationConverted, sddmUser.userId().nativeId(), sddmUser.groupId().nativeId())) {
         return;
@@ -137,6 +148,13 @@ ActionReply SddmAuthHelper::sync(const QVariantMap &args)
         copyFile(plasmarcSource.path(), plasmarcDestination.path());
     }
 
+    // copy kscreen config
+    if (!args[QStringLiteral("kscreen-config")].isNull()) {
+        const QString destinationDir = sddmHomeDirPath + "/.local/share/kscreen/";
+        QSet<QString> done;
+        copyDirectoryRecursively(args[QStringLiteral("kscreen-config")].toString(), destinationDir, done);
+    }
+
     // write cursor theme, NumLock preference, and scaling DPI to config file
     ActionReply reply = ActionReply::HelperErrorReply();
     QSharedPointer<KConfig> sddmConfig = openConfig(args[QStringLiteral("kde_settings.conf")].toString());
@@ -189,6 +207,8 @@ ActionReply SddmAuthHelper::reset(const QVariantMap &args)
     QFile::remove(sddmConfigLocation.path() + QStringLiteral("/kdeglobals"));
     QFile::remove(sddmConfigLocation.path() + QStringLiteral("/plasmarc"));
 
+    QDir(sddmHomeDirPath + "/.local/share/kscreen/").removeRecursively();
+
     // remove cursor theme, NumLock preference, and scaling DPI from config file
     ActionReply reply = ActionReply::HelperErrorReply();
     QSharedPointer<KConfig> sddmConfig = openConfig(args[QStringLiteral("kde_settings.conf")].toString());
@@ -247,7 +267,6 @@ ActionReply SddmAuthHelper::save(const QVariantMap &args)
             continue;
         }
 
-        QSharedPointer<KConfig> config;
         QString fileName = configFields[0];
         QString groupName = configFields[1];
         QString keyName = configFields[2];
